@@ -1,3 +1,4 @@
+#include <iconv.h>
 #include <cstdio>
 #include <cstring>
 #include <cerrno>
@@ -8,7 +9,7 @@ using namespace htmlcxx;
 
 CharsetConverter::CharsetConverter(const string &from, const string &to) throw (Exception)
 {
-	mIconvDescriptor = iconv_open(from.c_str(), to.c_str());
+	mIconvDescriptor = iconv_open(to.c_str(), from.c_str());
 	if (mIconvDescriptor == (iconv_t)(-1))
 	{
 		const char *error_str = strerror(errno);
@@ -29,7 +30,7 @@ string CharsetConverter::convert(const string &input)
 	const char *inbuf = input.c_str();
 	size_t inbytesleft = input.length();
 
-	size_t outbuf_len = input.length();
+	size_t outbuf_len = 2 * input.length();
 	char *outbuf_start = new char[outbuf_len];
 	char *outbuf = outbuf_start;
 	size_t outbytesleft = outbuf_len;
